@@ -1,7 +1,7 @@
 """hammad.pydantic.models"""
 
 from typing import TYPE_CHECKING
-from ...based.utils import auto_create_lazy_loader
+from ..._core._utils._import_utils import _auto_create_getattr_loader
 
 if TYPE_CHECKING:
     from .arbitrary_model import ArbitraryModel
@@ -20,7 +20,7 @@ __all__ = (
 )
 
 
-__getattr__ = auto_create_lazy_loader(__all__)
+__getattr__ = _auto_create_getattr_loader(__all__)
 
 
 def __dir__() -> list[str]:
